@@ -7,10 +7,11 @@ use parent 'Exporter';
 use charnames qw( :full );
 use Carp;
 
-our $VERSION   = '0.04';
-our @EXPORT    = qw( dumpstr );
+our $VERSION   = '0.05';
+our @EXPORT    = qw( dump_hex dump_dec dump_oct dump_bin dump_names dumpstr );
 our @EXPORT_OK = qw( dump_string );
 
+# TODO: remove dumpstr/dump_string in next release
 *dump_string = \&dumpstr;
 
 use constant DEFAULT_MODE => 'hex';
@@ -32,6 +33,52 @@ my %sub_for = (
     names => sub { map { charnames::viacode(ord) || UNKNOWN_NAME } @_ },
 );
 
+# TODO: we'll DRY this out when we ditch dumpstr
+sub dump_hex {
+    if (@_ != 1) {
+        carp 'dump_hex() expects one argument';
+        return;
+    }
+
+    return dumpstr('hex', @_);
+}
+
+sub dump_dec {
+    if (@_ != 1) {
+        carp 'dump_dec() expects one argument';
+        return;
+    }
+
+    return dumpstr('dec', @_);
+}
+
+sub dump_oct {
+    if (@_ != 1) {
+        carp 'dump_oct() expects one argument';
+        return;
+    }
+
+    return dumpstr('oct', @_);
+}
+
+sub dump_bin {
+    if (@_ != 1) {
+        carp 'dump_bin() expects one argument';
+        return;
+    }
+
+    return dumpstr('bin', @_);
+}
+
+sub dump_names {
+    if (@_ != 1) {
+        carp 'dump_names() expects one argument';
+        return;
+    }
+
+    return dumpstr('names', @_);
+}
+
 sub dumpstr {
     my ($mode, $string);
 
@@ -68,95 +115,96 @@ String::Dump - Dump strings of characters or bytes for printing and debugging
 
 =head1 VERSION
 
-This document describes String::Dump version 0.04.
+This document describes String::Dump version 0.05.
 
 =head1 SYNOPSIS
 
     use String::Dump;
 
-    say 'hex: ', dumpstr($string);  # hex mode by default
-    say 'oct: ', dumpstr(oct => $string);  # octal mode
+    say 'hex: ', dump_hex($string);  # hex mode
+    say 'oct: ', dump_oct($string);  # octal mode
 
 =head1 DESCRIPTION
 
-This module provides the C<dumpstr> function and exports it by default.  Those
-who prefer their function names unabridged may manually export C<dump_string>
-instead.  When debugging or reviewing strings containing non-ASCII or
-non-printing characters, C<dumpstr> is your friend.  It's a simple utility to
-view the characters or bytes of your string in several different formats, such
-as hex, octal, decimal, Unicode names, and more.
+When debugging or reviewing strings containing non-ASCII or non-printing
+characters, String::Dump is your friend.  It provides simple functions to
+return a dump of the characters or bytes of your string in several different
+formats, such as hex, octal, decimal, Unicode names, and more.
 
 An OO interface is forthcoming with additional options and the ability to
 reuse them among multiple calls.  Some benefits will include the ability to
 set the delimiter between characters, set padding for the characters, and
 force a string to be treated as a string of characters or a series of bytes.
-Don't worry, the C<dumpstr> function will remain simple.
+Don't worry, the standard functions will remain simple.
 
-=head2 dumpstr($mode, $string)
+Check out L<String::Dump::Debugging> for tips on debugging Unicode and encoded
+strings with this module.  Also check out the bundled command-line tool
+L<dumpstr>.
 
-The mode is optional and defaults to C<hex>.  Other valid modes are C<dec>,
-C<oct>, C<bin>, and C<names>, and are described below.  The string may either
-be a series of Unicode characters or binary bytes.
+=head1 FUNCTIONS
 
-=head2 Modes
+The following functions are all exported by default.  This is convenient for
+debugging and one-liners, but explicitly exporting individual functions is
+recommended in other cases.  It's up to you!
 
-=head3 hex
+These functions all accept a single argument: the string to dump, which may
+either be a Perl internal string or an encoded series of bytes.
 
-Hexadecimal (base 16) mode.  This is the default when only a string is passed
-without the mode.
+=head2 dump_hex($string)
+
+Hexadecimal (base 16) mode.
 
     use utf8;
     # string of 6 characters
-    say dumpstr('Ĝis! ☺');  # 11C 69 73 21 20 263A
-    say dumpstr(hex => 'Ĝis! ☺');  # same thing
+    say dump_hex('Ĝis! ☺');  # 11C 69 73 21 20 263A
 
     no utf8;
     # series of 9 bytes
-    say dumpstr('Ĝis! ☺');  # C4 9C 69 73 21 20 E2 98 BA
+    say dump_hex('Ĝis! ☺');  # C4 9C 69 73 21 20 E2 98 BA
 
 For a lowercase hex dump, simply pass the response to C<lc>.
 
-    say lc dumpstr('Ĝis! ☺');  # 11c 69 73 21 20 263a
+    say lc dump_hex('Ĝis! ☺');  # 11c 69 73 21 20 263a
 
-=head3 dec
+=head2 dump_dec($string)
 
 Decimal (base 10) mode.
 
     use utf8;
-    say dumpstr(dec => 'Ĝis! ☺');  # 284 105 115 33 32 9786
+    say dump_dec('Ĝis! ☺');  # 284 105 115 33 32 9786
 
     no utf8;
-    say dumpstr(dec => 'Ĝis! ☺');  # 196 156 105 115 33 32 226 152 186
+    say dump_dec('Ĝis! ☺');  # 196 156 105 115 33 32 226 152 186
 
-=head3 oct
+=head2 dump_oct($string)
 
 Octal (base 8) mode.
 
     use utf8;
-    say dumpstr(oct => 'Ĝis! ☺');  # 434 151 163 41 40 23072
+    say dump_oct('Ĝis! ☺');  # 434 151 163 41 40 23072
 
     no utf8;
-    say dumpstr(oct => 'Ĝis! ☺');  # 304 234 151 163 41 40 342 230 272
+    say dump_oct('Ĝis! ☺');  # 304 234 151 163 41 40 342 230 272
 
-=head3 bin
+=head2 dump_bin($string)
 
 Binary (base 2) mode.
 
     use utf8;
-    say dumpstr(bin => 'Ĝis! ☺');
+    say dump_bin('Ĝis! ☺');
     # 100011100 1101001 1110011 100001 100000 10011000111010
 
     no utf8;
-    say dumpstr(bin => 'Ĝis! ☺');
+    say dump_bin('Ĝis! ☺');
     # 11000100 10011100 1101001 1110011 100001 100000 11100010 10011000 10111010
 
-=head3 names
+=head2 dump_names($string)
 
 Named Unicode character mode.  Unlike the various numeral modes above, this
 mode uses ', ' for the delimiter.
 
     use utf8;
-    say dumpstr(names => 'Ĝis! ☺');
+    say dump_names('Ĝis! ☺');
     # LATIN CAPITAL LETTER G WITH CIRCUMFLEX, LATIN SMALL LETTER I,
     # LATIN SMALL LETTER S, EXCLAMATION MARK, SPACE, WHITE SMILING FACE
 
@@ -164,7 +212,7 @@ This mode makes no sense for a series of bytes, but it still works if that's
 what you really want!
 
     no utf8;
-    say dumpstr(names => 'Ĝis! ☺');
+    say dump_names('Ĝis! ☺');
     # LATIN CAPITAL LETTER A WITH DIAERESIS, STRING TERMINATOR,
     # LATIN SMALL LETTER I, LATIN SMALL LETTER S, EXCLAMATION MARK,
     # SPACE, LATIN SMALL LETTER A WITH CIRCUMFLEX, START OF STRING,
@@ -173,48 +221,6 @@ what you really want!
 The output in the examples above has been manually split into multiple lines
 for the layout of this document.
 
-=head2 Tips
-
-=head3 Literal strings
-
-When dumping literal strings in your code, as in the examples above, use the
-L<utf8> pragma when strings of Unicode characters are desired and don't use it
-or disable it when series of bytes are desired.  The pragma may also be
-lexically enabled or disabled.
-
-    use utf8;
-
-    {
-        no utf8;
-        say dumpstr('Ĝis! ☺');  # C4 9C 69 73 21 20 E2 98 BA
-    }
-
-    say dumpstr('Ĝis! ☺');  # 11C 69 73 21 20 263A
-
-=head3 Command-line input and filehandles
-
-The simplest way to ensure that you're working with strings of characters from
-all of your basic sources of input is to use the L<utf8::all> pragma.  This
-extends the utf8 pragma to automatically convert command-line arguments
-provided by C<@ARGV>, user-defined filehandles, as well as C<STDIN>, among
-others.
-
-=head3 Other sources of input
-
-To handle strings provided by other sources of input, such as from network
-protocols or a web server request, pass the value to
-L<Encode::decode_utf8|Encode>, which will return the desired string.
-
-    use Encode;
-
-    say dumpstr( decode_utf8($string) );
-
-To convert a variable in-place, pass it to utf8::decode instead.
-
-    utf8::decode($string);
-
-    say dumpstr($string);
-
 =head1 CONTRIBUTIONS
 
 This is an early release of String::Dump.  Feedback is appreciated!  To give
@@ -226,6 +232,10 @@ are welcome at L<https://github.com/patch/string-dump-pm5>.
 
 =over
 
+=item * L<dumpstr> - Dump strings of characters on the command line
+
+=item * L<String::Dump::Debugging> - String debugging tips with String::Dump
+
 =item * L<Template::Plugin::StringDump> - String::Dump plugin for TT
 
 =item * L<Data::HexDump> - Simple hex dumping using the default output of the
